@@ -15,8 +15,8 @@
 # You should have received a copy of the GNU General Public License along with
 # this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from PySide2 import QtCore, QtGui, QtWidgets  #pylint: disable=import-error
-from PySide2.QtUiTools import loadUiType      #pylint: disable=no-name-in-module
+from PySide6 import QtCore, QtGui, QtWidgets
+from PySide6.QtUiTools import loadUiType
 
 import trspectrometer
 
