@@ -16,9 +16,7 @@
 # this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import os
-import logging
 import warnings
-#from threading import Lock
 
 import tomlkit
 from PySide6 import QtCore, QtGui, QtWidgets
@@ -34,6 +32,7 @@ import hardware as hw
 import datastorage as ds
 from qtwidgets import FlowLayout
 
+from signalstorage import signals
 from utils import si_unit_factor
 
 #: Default settings to place in configuration file if not existing already.
@@ -76,11 +75,7 @@ class DataPanel(QtWidgets.QWidget, loadUiType(__file__.split(".py")[0] + ".ui")[
     UI panel to facilitate the collection and viewing of data.
 
     :param parent: Parent of the QWidget.
-    """
-
-    #: Signal to respond to the end of acquisition.
-    acquisition_completed = Signal(Exception)
-    
+    """    
     def __init__(self, parent=None):
         super().__init__(parent)
         self.setupUi(self)
@@ -89,10 +84,11 @@ class DataPanel(QtWidgets.QWidget, loadUiType(__file__.split(".py")[0] + ".ui")[
         config.add_defaults(tomlkit.parse(_default_config))
 
         # Listen for when data set is changed
-        ds.signals.data_changed.connect(self._data_changed)
-        ds.signals.data_updated.connect(self._data_updated)
-        ds.signals.raw_selection_changed.connect(self._raw_selection_changed)
-        self.acquisition_completed.connect(self._acquisition_complete)
+        signals.data_changed.connect(self._data_changed)
+        signals.raw_data_updated.connect(self._data_updated)
+        signals.raw_selection_changed.connect(self._raw_selection_changed)
+        signals.acquisition_started.connect(self._acquisition_started)
+        signals.acquisition_stopped.connect(self._acquisition_complete)
 
         # Setup pyqtgraph plot areas
         pg.setConfigOptions(imageAxisOrder='row-major', antialias=True)
@@ -710,35 +706,29 @@ class DataPanel(QtWidgets.QWidget, loadUiType(__file__.split(".py")[0] + ".ui")[
             if not d.is_initialised():
                 raise RuntimeWarning("Selected acquisition method is not available and ready.")
             self._acquisition = d
-            self._acquisition.register_completion_callback(self._emit_acquisition_completed)
             self._acquisition.start()
-            self.startPushButton.setText("Stop")
-            self.timeGroupBox.setEnabled(False)
-            self.methodComboBox.setEnabled(False)
-            self.densitySpinBox.setEnabled(False)
-            config.mainwindow.menuDataset.setEnabled(False)
-            for i in range(config.mainwindow.tabWidget.count()):
-                config.mainwindow.tabWidget.setTabEnabled(i, i == config.mainwindow.tabWidget.currentIndex())
-            self._save_ui_config()
-            config.mainwindow.statusbar.showMessage("Acquisition started" + f" to {ds.d_path}" if ds.d_path else ".")
+            signals.acquisition_started.emit()
+            
 
-
-    def _emit_acquisition_completed(self, error=None):
+    def _acquisition_started(self):
         """
-        Wrap the Qt Signal emit() so the acquisition thread because:
-          1. Other threads shouldn't mess with things inside the Qt thread.
-          2. The emit function signature doesn't stay constant so is unable to be removed from acquisition callback lists.
-        
-        The signal is connected to :meth:`_acquisition_complete`.
+        Handle the signal for starting of acquisition. Disable controls etc.
         """
-        self.acquisition_completed.emit(error)
+        self.startPushButton.setText("Stop")
+        self.timeGroupBox.setEnabled(False)
+        self.methodComboBox.setEnabled(False)
+        self.densitySpinBox.setEnabled(False)
+        config.mainwindow.menuDataset.setEnabled(False)
+        for i in range(config.mainwindow.tabWidget.count()):
+            config.mainwindow.tabWidget.setTabEnabled(i, i == config.mainwindow.tabWidget.currentIndex())
+        self._save_ui_config()
+        config.mainwindow.statusbar.showMessage("Acquisition started" + f" to {ds.d_path}" if ds.d_path else ".")
 
 
     def _acquisition_complete(self, error=None):
         """
-        Handle the signal for completion of acquisition.
+        Handle the signal for completion of acquisition. Re-enable controls etc.
         """
-        self._acquisition.unregister_completion_callback(self._emit_acquisition_completed)
         self._acquisition = None
         self.startPushButton.setText("Start")
         self.timeGroupBox.setEnabled(True)
@@ -1117,7 +1107,7 @@ class DataPanelScansWidget(QtWidgets.QFrame, loadUiType(os.path.join(os.path.dir
                 excluded_scans.append(i)
         ds.t["raw"].attrs["exclude_scans"] = excluded_scans
         # Notify any listeners of the change to selection
-        ds.signals.raw_selection_changed.emit()
+        signals.raw_selection_changed.emit()
 
     def eventFilter(self, target, event):
         """Event filter to handle mouse movements over scan selection checkboxes and highlight matching scan trace."""
