@@ -1,4 +1,4 @@
-# Copyright 2020 Patrick C. Tapping
+# Copyright 2021 Patrick C. Tapping
 #
 # This program is free software: you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -34,10 +34,9 @@ import zarr
 from scipy.stats import norm
 from scipy.ndimage import median_filter
 from PySide6.QtWidgets import QFileDialog, QMessageBox
-from PySide6 import QtCore
-from PySide6.QtCore import Signal
 
 import configuration as config
+from signalstorage import signals
 from ufsfile import UFSData
 from utils import clean_filename, now_string
 
@@ -70,31 +69,6 @@ root_attrs = {
 }
 
 
-class SignalStorage(QtCore.QObject):
-    """
-    A class which is able to store and send Qt Signals.
-
-    Since Signals can only be sent by QObjects, an instance of this class
-    is used to store and emit the various Signals.
-    """
-
-    #: Signal that new data has been loaded.
-    #: If the parameter is ``True```, it indicates that a complete data set was loaded from a file,
-    #: and thus user interface controls should be updated to match. If ``False``, it indicates that
-    #: the new data is from an acquisition process, and UI updates should not be performed.
-    data_changed = Signal(bool)
-    
-    #: Signal that data has been updated.
-    #: The parameters are lists of scan, time, wavelength indices which may have changed.
-    #: None indicates that all elements have potentially changed.
-    data_updated = Signal(list, list, list)
-
-    #: Signal that the selection of raw data traces has changed.
-    raw_selection_changed = Signal()
-
-signals = SignalStorage()
-
-
 def new_zarr(location=""):
     """
     Generate a new empty data set.
