@@ -19,9 +19,9 @@ from time import sleep, monotonic
 import warnings
 
 import numpy as np
-import zarr
 
 import configuration as config
+from signalstorage import signals
 import hardware as hw
 import datastorage as ds
 from utils import AcquisitionError, AcquisitionAbortedWarning, no_infs, si_unit_factor, status_message, now_string
@@ -208,7 +208,7 @@ class TA_SteppedAcquisition(Acquisition):
         ds.d["raw"].attrs["config"] = config.data.copy()
 
         # Notify that the data structures have changed
-        ds.signals.data_changed.emit(False)  # Don't update UI
+        signals.data_changed.emit(False)  # Don't update UI
 
         # Start up the acquisition thread
         self._acq_thread = Thread(name="Acquisition", target=self._start_acq, daemon=True, kwargs={
@@ -406,11 +406,8 @@ class TA_SteppedAcquisition(Acquisition):
                         self._log.warning(msg)
                         continue
 
-                    # Notify that data has been updated
-                    for cb in self._update_callbacks.copy():
-                        cb([s_i], [t_i], None)
-                    # And trigger the Qt data update signal
-                    ds.signals.data_updated.emit([s_i], [t_i], None)
+                    # Trigger the data update signal
+                    signals.raw_data_updated.emit([s_i], [t_i], None)
                     
                     # Increment time index
                     t_i += 1
@@ -461,9 +458,7 @@ class TA_SteppedAcquisition(Acquisition):
             self._log.warning("Error stopping Chopper.")
 
         self._log.info("Stopped acquisition.")
-        # Iterate over copy of callbacks set so it can be modified if needed
-        for cb in self._completion_callbacks.copy():
-            cb(error)
+        signals.acquisition_stopped.emit(error)
         self._acq_thread = None
 
             
