@@ -262,8 +262,8 @@ class TA_SweptAcquisition(Acquisition):
             msg = "Waiting for chopper to spin up."
             self._log.info(msg)
             status_message(msg)
-            clock = monotonic()
-            while monotonic() < clock + 4.0:
+            start_time = monotonic()
+            while monotonic() < start_time + 5.0:
                 if self._acq_stop.is_set():
                     raise AcquisitionAbortedWarning()
                 sleep(0.1)
@@ -365,12 +365,12 @@ class TA_SweptAcquisition(Acquisition):
                         self._delay.set_velocity(3e-9)      # 3ns/s
                         self._delay.set_acceleration(2e-8)  # 20ns/s/s
                         self._delay.set_delay(delay_target)
-                        clock = monotonic()
+                        start_time = monotonic()
                         while self._delay.is_moving():
                             if self._acq_stop.is_set():
                                 self._delay.stop()
                                 raise AcquisitionAbortedWarning()
-                            if monotonic() > (clock + 30.0):
+                            if monotonic() > (start_time + 30.0):
                                 raise AcquisitionError("Timeout waiting for delay movement.")
                             sleep(0.1)
                     
@@ -397,7 +397,7 @@ class TA_SweptAcquisition(Acquisition):
                     self._delay.set_delay(min(self._delay.max_delay(), si_f*(t_start + t[sweep_ranges[r_i][1]])))
 
                     # Wait for acquisition to finish
-                    clock = monotonic()
+                    start_time = monotonic()
                     acquisition_failure = False
                     while not (interface_done.is_set() and detector_done.is_set()):
                         if self._acq_stop.is_set():
@@ -405,8 +405,8 @@ class TA_SweptAcquisition(Acquisition):
                             self._detector.stop()
                             self._delay.stop()
                             raise AcquisitionAbortedWarning()
-                        if monotonic() > (clock + 60.0):
-                            # TODO: Could decide on timeout value depending on number of samples and laser rep rate
+                        if monotonic() > (start_time + spectra_count/laser_reprate + 10.0):
+                            # Acquisition is taking longer than expected...
                             acquisition_failure = True
                             break
                         sleep(0.01)
