@@ -69,11 +69,11 @@ import numpy as np
 import numpy.typing as npt
 import tomlkit
 import pluginlib
-from PySide2 import QtCore, QtWidgets
-from PySide2.QtCore import Signal         #pylint: disable=no-name-in-module
+from PySide6 import QtCore, QtWidgets
+from PySide6.QtCore import Signal
 
-import configuration as config            #pylint: disable=import-error
-import hardware as hw                     #pylint: disable=import-error
+import configuration as config
+import hardware as hw
 
 
 #: Default settings to place in configuration file if not existing already.
@@ -268,7 +268,7 @@ class Detector():
         else:
             raise RuntimeWarning("Attempted to unregister an unknown function for acquisition callbacks.")
 
-    def get_triggermodes(self) -> tuple[str]:
+    def get_triggermodes(self): # -> tuple[str]:
         """
         List the trigger modes available to the detector.
 
@@ -294,7 +294,7 @@ class Detector():
         """
         return "internal"
     
-    def get_exposure_limits(self) -> tuple[float]:
+    def get_exposure_limits(self): # -> tuple[float]:
         """
         Get the minimum and maximum allowed exposure times, in seconds.
 
@@ -318,7 +318,7 @@ class Detector():
         """
         pass
 
-    def get_wavelength_limits(self) -> tuple[float]:
+    def get_wavelength_limits(self): # -> tuple[float]:
         """
         Get the minimum and maximum allowed values for the central wavelength selection, in
         nanometres.
@@ -343,7 +343,7 @@ class Detector():
         """
         pass
 
-    def get_gratings(self) -> tuple[Optional[str]]:
+    def get_gratings(self): # -> tuple[Optional[str]]:
         """
         List the gratings available for the detector.
 
@@ -500,7 +500,7 @@ config.add_defaults(tomlkit.parse(_default_config))
 devices = [None for _ in config.data["hardware"]["detector"]]
 
 # Bypass this code block if module was imported by sphinx documentation generation utility
-if not "sphinx-build" in os.path.basename(sys.argv[0]):
+if not "sphinx" in sys.argv[0]:
     # Look for valid plugin classes
     try:
         plugin_paths = [ os.path.join(d, "detector") for d in config.data["directories"]["plugins"] ]
