@@ -35,6 +35,10 @@ mode = "raw"
 samples = 50
 reference_raw = ""
 reference_deltaA = ""
+
+[scope.crosshair]
+# An RGBA colour for the crosshairs
+colour = [0, 255, 0, 128]
 """
 
 # Create default config entries if required
